@@ -218,7 +218,7 @@ class CM(object):
                 raise Exception(r['error'])
 
             if self.con:
-                sys.stderr.write(self.cfg['error_prefix']+' '+r['error']+'\n')
+                sys.stderr.write(self.cfg['error_prefix']+' '+r['error']+'!\n')
 
         return r
 
@@ -330,7 +330,7 @@ class CM(object):
 
                 if cm_help:
                    print ('')
-                   print ('Collective database actions:')
+                   print ('Collective database actions for this artifact:')
                    print ('')
 
                    for d in sorted(dir(self.default_module)):
